@@ -1,4 +1,4 @@
-from fx-iqoption import IQOption
+from fxiqoption import IQOption
 
 
 api = IQOption('email','password','DEMO')
